Documentation
¶
Overview ¶
Package bgproc starts a process in "background", i.e. a from terminal detached process.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Process ¶
Process holds the name of the program and its arguments. PID is set after calling Start and if syscall.ForkExec has been used (not available on Windows).
func New ¶
New creates and returns a new instance of Process. The parameter name is the absolute path to the program to start.
Click to show internal directories.
Click to hide internal directories.